@@ -185,9 +185,8 @@
         <translation>E&amp;dita</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="138"/>
         <source>&amp;Create</source>
-        <translation>&amp;Crea</translation>
+        <translation type="vanished">&amp;Crea</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="214"/>
@@ -331,6 +330,11 @@ Creeu un nou acoblador en aquest cas.</translation>
         <source>Could not open file</source>
         <translation>No he pogut obrir el fitxer</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="138"/>
+        <source>C&amp;reate</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="302"/>
         <source>Select dock to move</source>
