@@ -185,9 +185,8 @@
         <translation>&amp;編集</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="138"/>
         <source>&amp;Create</source>
-        <translation>&amp;作成</translation>
+        <translation type="vanished">&amp;作成</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="214"/>
@@ -330,6 +329,11 @@ Creating a new dock instead.</source>
         <source>Could not open file</source>
         <translation>ファイルを開くことができません</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="138"/>
+        <source>C&amp;reate</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="302"/>
         <source>Select dock to move</source>
