@@ -177,11 +177,6 @@
         <source>&amp;Edit</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="138"/>
-        <source>&amp;Create</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="214"/>
         <source>Dock name</source>
@@ -313,6 +308,11 @@ Creating a new dock instead.</source>
         <source>Could not open file</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="138"/>
+        <source>C&amp;reate</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="302"/>
         <source>Select dock to move</source>
