@@ -185,9 +185,8 @@
         <translation>&amp;Redigera</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="138"/>
         <source>&amp;Create</source>
-        <translation>&amp;Skapa</translation>
+        <translation type="vanished">&amp;Skapa</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="214"/>
@@ -331,6 +330,11 @@ Skapar istället en ny docka.</translation>
         <source>Could not open file</source>
         <translation>Kunde inte öppna fil</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="138"/>
+        <source>C&amp;reate</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="302"/>
         <source>Select dock to move</source>
