@@ -182,9 +182,8 @@
         <translation>&amp;Düzenle</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="138"/>
         <source>&amp;Create</source>
-        <translation>&amp;Oluştur</translation>
+        <translation type="vanished">&amp;Oluştur</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="214"/>
@@ -325,6 +324,11 @@ Creating a new dock instead.</source>
         <source>Could not open file</source>
         <translation>Dosya açılamadı</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="138"/>
+        <source>C&amp;reate</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="302"/>
         <source>Select dock to move</source>
